package com.huimv.authority.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.authority.mapper.GroupMenuMapper;
import com.huimv.authority.entity.Group;
import com.huimv.authority.mapper.GroupMapper;
import com.huimv.authority.entity.GroupMenu;
import com.huimv.authority.service.IGroupService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.authority.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author astupidcoder
 * @since 2021-09-09
 */
@Service
public class GroupServiceImpl extends ServiceImpl<GroupMapper, Group> implements IGroupService {
    @Autowired
    private GroupMapper GroupMapper;
    @Autowired
    private GroupMenuMapper groupMenuMapper;

    @Override
    public Result updateGroup(Integer groupId, String groupName, String remark) {
        try {
            Group group = this.GroupMapper.selectById(groupId);
            if (group == null) {
                return new Result(10002,"请选择数据",false);
            }
            group.setGroupName(groupName);
            group.setRemark(remark);
            GroupMapper.updateById(group);
            return new Result(10000,"修改成功",true);
        }catch (Exception e){
            return new Result(10001,"修改失败",false);
        }
    }

    @Override
    @Transactional
    public Result removeGroup(Integer groupId) {
        try {
            Group group = this.GroupMapper.selectById(groupId);
            if (group == null) {
                return new Result(10002,"请选择数据",false);
            }
            // 删除权限组
            this.GroupMapper.deleteById(groupId);
            // 删除权限组关联菜单
            QueryWrapper<GroupMenu> groupMenuQueryWrapper = new QueryWrapper<>();
            groupMenuQueryWrapper.eq("group_id",groupId);
            groupMenuMapper.delete(groupMenuQueryWrapper);
            return new Result(10000,"删除成功",true);
        }catch (Exception e){
            return new Result(10001,"删除失败",false);
        }
    }

    @Override
    public  IPage<Group> listGroup(int pageNum, int pageSize, String searchStr) {


        return this.page(new Page<>(pageNum, pageSize),new QueryWrapper<Group>().orderByDesc("id"));
    }

    @Override
    public Result addGroup(String groupName, String remark) {
        try {
            Group group = new Group();
            group.setGroupName(groupName);
            group.setRemark(remark);
            GroupMapper.insert(group);
            return new Result(10000,"添加成功",true);
        }catch (Exception e){
            return new Result(10001,"添加失败",false);
        }
    }
}
